.. _configs:

*******
Configs
*******

Configs provide library-level storage of configuration settings. These settings
can be made in code or from environment variables.

.. automodule:: networkx.utils.configs

.. autoclass:: config
.. autoclass:: NetworkXConfig
.. autoclass:: Config
